# AutoRA Workflow

Workflow management tools for AutoRA. 

## User Guide

You will need:

- `python` 3.8 or greater: [https://www.python.org/downloads/](https://www.python.org/downloads/)

Install the workflow package (as part of `autora`):

```shell
pip install --upgrade "autora"
```

> 💡We recommend using a `python` environment manager like `virtualenv`.

Print the help for the CLI utility by running:
```shell
python -m autora.workflow --help
```

For more information, see the
[documentation](https://autoresearch.github.io/autora/user-guide/workflow/).
